# CCR Human Behaviour Framework

> [!INFO]Quote
> 	> This framework allows for biases, habituation and other cognitive processes that shape human perception of climate change and the influence of social norms, social learning and other social processes on spreading information and factors that shape decision-making and behaviour ^[@beckage2022].

We applied the framework for representing human behaviour that consists of **cognition, contagion and behavioural response (CCR framework)** ^[@beckage2022]:

=== "Cognition"

	> **Cognition** represents the human processing of information around the ecological system.

=== "Contagion"

	> **Contagion** represents spreading information, beliefs and behaviour through social networks.

=== "Response"

	> **Response** is the resultant behaviour or action.

The `ABSESpy` fully embedded the three aspects of human behaviour in a different part of the model:

1. **Cognition**: developed as an essential feature of each `Actor`.
2. **Contagion**: human model can automatically [generate SEN for modelling](#TODO) this.
3. **Response**: customised by users under the [IAD framework](#TODO) ^[@ostrom2005].
